@@ -89,7 +89,7 @@ void output_header(Project* project, char* title, char* script_name, NaviType na
     o(      "</head>\n"
             "<body>\n"
             "<a name=\"top\"></a>\n"
-            "<h1 id=\"toptitle\" title=\"Starbug1\"><a href=\"http://www.starbug1.com/\"><img src=\"%s/../index.%s/%s/setting_file/top_image\" alt=\"Starbug1\" /></a></h1>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url);
+            "<h1 id=\"toptitle\" title=\"Starbug1\"><a href=\"http://starbug1.com/\"><img src=\"%s/../index.%s/%s/setting_file/top_image\" alt=\"Starbug1\" /></a></h1>\n", cgiScriptName, get_ext(cgiScriptName), g_project_code_4_url);
     o(      "<div id='pankuzu'>\n"
             "<ul>\n");
     o(      "\t<li><a href='%s/top/' title=\"%s\">", cgiScriptName, _("display sub projects list at top page.")); h(string_rawstr(top_project_name)); o("</a> &gt; </li>\n");
@@ -130,7 +130,7 @@ void output_footer()
             "\t</a>\n"
             "</p>\n"
             "<div><address>Powered by cgic &amp; SQLite3.</address></div>\n"
-            "<div><address><a href=\"http://www.starbug1.com/\">Starbug1</a> version: %s. %s.</address></div>\n"
+            "<div><address><a href=\"http://starbug1.com/\">Starbug1</a> version: %s. %s.</address></div>\n"
             "</div>\n"
             "</div>\n"
             "</body>\n</html>\n", cgiScriptName, VERSION, COPYRIGHT);
@@ -177,7 +177,7 @@ void top_action()
     o("<div class=\"description\">\n");
     o("\t%s\n", _("[mail notify messages]"));
     o("\t<ul>\n"
-      "\t\t<li><a href=\"http://www.starbug1.com/\">http://www.starbug1.com/</a></li>\n"
+      "\t\t<li><a href=\"http://starbug1.com/\">http://starbug1.com/</a></li>\n"
       "\t</ul>\n");
     o("</div>\n");
     o("</div>\n");
@@ -597,7 +597,6 @@ void update_elements(Database* db)
     if ((cgiFormStringMultiple("field_ids", &ids)) == cgiFormNotFound) {
         die("cannot find field_ids.");
     }
-    d("1");
     while (ids[++i]) {
         int j;
         char* id = ids[i];
@@ -607,7 +606,6 @@ void update_elements(Database* db)
         Iterator* it;
         ElementType* et_a = element_type_new();
 
-    d("2 id:%s\n", id);
         et_a = db_get_element_type(db, atoi(id), et_a);
 
         sprintf(name, "field%s.name", id);
@@ -707,7 +705,6 @@ void update_elements(Database* db)
         element_type_free(et_a);
     }
     cgiStringArrayFree(ids);
-    d("end");
 }
 void new_item_action()
 {
